@@ -51,5 +51,15 @@
                                           names(formals(raster::projectRaster)),
                                           names(formals(determineFilename)),
                                           names(formals(writeOutputs)),
-                                          unlist(lapply(methods("postProcess"), function(x) names(formals(x))))))
+                                          unlist(lapply(methods("postProcess"),
+                                                        function(x) names(formals(x))))))
 
+
+
+#' The \code{reproducible} package environment
+#'
+#' Environment used internally to store internal package objects and methods.
+#'
+#' @keywords internal
+#' @rdname pkgEnv
+.pkgEnv <- new.env(parent = emptyenv())
