@@ -3,8 +3,7 @@ test_that("Checksums read and written correctly", {
 
   sampleDir <- system.file("maps", package = "quickPlot")
   sampleFiles <- list.files(sampleDir, pattern = "[.]tif", full.names = TRUE)
-  tmpdir <- file.path(tempdir(), "test_checksums") %>%
-    checkPath(create = TRUE)
+  tmpdir <- file.path(tempdir(), "test_checksums") %>% checkPath(create = TRUE)
   on.exit(unlink(dirname(tmpdir), recursive = TRUE), add = TRUE)
 
   expect_true(all(file.copy(sampleFiles, tmpdir)))
@@ -17,7 +16,7 @@ test_that("Checksums read and written correctly", {
              "f21251dcdf23dde0", "86e342cfc6876b7d")
 
   # 1. read Checksums without CHECKSUMS.txt file
-  expect_error(Checksums(tmpdir))
+  expect_true(NROW(Checksums(tmpdir))==0)
 
   # 2. read Checksums with empty CHECKSUMS.txt file
   expect_true(file.create(csf))
