@@ -1,4 +1,8 @@
 test_that("fastMask produces correct results", {
+  testInitOut <- testInit(needGoogle = FALSE, c("sp", "raster"))
+  on.exit({
+    testOnExit(testInitOut)
+  }, add = TRUE)
   Sr1 <- sp::Polygon(cbind(c(2, 4, 4, 1, 2), c(2, 3, 5, 4, 2))) # nolint
   Sr2 <- sp::Polygon(cbind(c(5, 4, 2, 5), c(2, 3, 2, 2))) # nolint
   Sr3 <- sp::Polygon(cbind(c(4, 4, 5, 7.4, 4), c(5, 3, 2, 5, 5))) # nolint
@@ -19,6 +23,7 @@ test_that("fastMask produces correct results", {
   ## mask
   newStack1 <- raster::stack(raster::mask(origStack, mask = shpDF))
   newStack2 <- fastMask(x = origStack, y = shpDF)
+
   if (utils::packageVersion("raster") <= "2.6.7") # change coming in package that will cause this to fail in next version
     expect_equal(newStack1, newStack2)
 
@@ -26,6 +31,49 @@ test_that("fastMask produces correct results", {
   newStack2 <- fastMask(x = origStack[[2]], y = shpDF)
   expect_equivalent(newStack1, newStack2)
 
+  # Run same as above but with different internal pathway
+  testthat::with_mock(
+    "raster::canProcessInMemory" = function(x, n) {
+      FALSE
+    },
+    suppressWarnings(newStack3 <- fastMask(x = origStack[[2]], y = shpDF))
+  )
+  newStack3[] <- newStack3[]
+  names(newStack3) <- names(newStack1)
+  expect_equivalent(newStack1, newStack3)
+  # Run same as above but with different internal pathway
+  gdalUtils::gdal_setInstallation()
+
+  # if it doesn't find gdal installed
+  hasGDALInstalled <- !is.null(getOption("gdalUtils_gdalPath"))
+
+  testthat::with_mock(
+    "raster::canProcessInMemory" = function(x, n) {
+      FALSE
+    },
+    "reproducible::isWindows" = function() {
+      TRUE
+    },
+    # The warning is "data type "LOG" is not available in GDAL -- not relevant here
+    {
+      if (hasGDALInstalled) {
+        if (identical(.Platform$OS.type, "windows")) {
+          warn <- capture_warnings(
+            newStack3 <- fastMask(x = origStack[[2]], y = shpDF)
+          )
+        } else {
+          warn <- capture_warnings(expect_error(
+            newStack3 <- fastMask(x = origStack[[2]], y = shpDF))
+          )
+        }
+        warn <- capture_warnings(
+          expect_error(
+            out <- fastMask(x = origStack[[2]], y = shpDF, cores = "none"), "needs to be passed")
+        )
+      }
+    }
+  )
+
   crs(shpDF) <- "+proj=lcc +lat_1=48 +lat_2=33 +lon_0=-100 +ellps=WGS84"
   crs(shp) <- "+proj=lcc +lat_1=48 +lat_2=33 +lon_0=-100 +ellps=WGS84"
   crs(origStack[[2]]) <- "+proj=lcc +lat_1=49 +lat_2=33 +lon_0=-100 +ellps=WGS84"
@@ -49,18 +97,26 @@ test_that("fastMask produces correct results", {
 
 })
 
-test_that("testing prepInputs with sf class objects", {
-  if (interactive()) {
-    testInitOut <- testInit(needGoogle = TRUE)
-    on.exit({
-      testOnExit(testInitOut)
-    }, add = TRUE)
-    BCR6_VT <- prepInputs(
+test_that("testing prepInputs with deauthorized googledrive", {
+  testInitOut <- testInit(needGoogle = FALSE, "googledrive")
+  on.exit({
+    testOnExit(testInitOut)
+  }, add = TRUE)
+
+  drive_deauth()
+  testthat::with_mock(
+    "reproducible::isInteractive" = function() {
+      FALSE
+    },
+    warn <- capture_warnings(BCR6_VT <- prepInputs(
       url = "https://drive.google.com/open?id=1sEiXKnAOCi-f1BF7b4kTg-6zFlGr0YOH",
       targetFile = "BCR6.shp",
       overwrite = TRUE
-    )
+    ))
+  )
+  expect_true(is(BCR6_VT, "Spatial"))
 
+  if (interactive()) {
     NFDB_PT <- Cache(
       prepInputs,
       url = "http://cwfis.cfs.nrcan.gc.ca/downloads/nfdb/fire_pnt/current_version/NFDB_point.zip",
